@@ -3,7 +3,7 @@ import sentry_sdk
 import logging
 from aws_xray_sdk.core import xray_recorder
 from aws_xray_sdk.core import patch_all
-from .aws_client.aws_client import AWSClient
+from framework_python import AWSClient
 
 
 # Initialize sentry, logger and AWS X-Ray
